@@ -4,9 +4,9 @@ import pickle
 import random
 import easydict
 import torch
+import os
 from typing import Optional, List, Any
 from functools import partial
-import os
 from copy import deepcopy
 
 from ding.config import compile_config, read_config
@@ -48,7 +48,7 @@ def collect_episodic_demo_data_for_drex(
     """
     cfg.env.collector_env_num = 1
     if not os.path.exists(save_cfg_path):
-        os.mkdir(save_cfg_path)
+        os.makedirs(save_cfg_path)
 
     # Create components: env, policy, collector
     if env_setting is None:
@@ -65,7 +65,9 @@ def collect_episodic_demo_data_for_drex(
         assert state_dict_path is not None
         state_dict = torch.load(state_dict_path, map_location='cpu')
     policy.collect_mode.load_state_dict(state_dict)
-    collector = EpisodeSerialCollector(cfg.policy.collect.collector, collector_env, collect_demo_policy)
+    collector = EpisodeSerialCollector(
+        cfg.policy.collect.collector, collector_env, collect_demo_policy, exp_name=cfg.exp_name
+    )
 
     policy_kwargs = {'eps': noise}
 
