@@ -1,5 +1,6 @@
 import numpy as np
 import dataclasses
+import treetensor.torch as ttorch
 from typing import Union, Dict, List
 
 
@@ -49,14 +50,19 @@ class OnlineRLContext(Context):
     env_episode: int = 0
     train_iter: int = 0
     train_data: Union[Dict, List] = None
+    train_output: Union[Dict, List[Dict]] = None
     # collect
     collect_kwargs: Dict = dataclasses.field(default_factory=dict)
+    obs: ttorch.Tensor = None
+    action: List = None
+    inference_output: Dict[int, Dict] = None
     trajectories: List = None
     episodes: List = None
     trajectory_end_idx: List = dataclasses.field(default_factory=list)
     # eval
     eval_value: float = -np.inf
     last_eval_iter: int = -1
+    eval_output: List = dataclasses.field(default_factory=dict)
 
     def __post_init__(self):
         # This method is called just after __init__ method. Here, concretely speaking,
@@ -73,9 +79,11 @@ class OfflineRLContext(Context):
     train_epoch: int = 0
     train_iter: int = 0
     train_data: Union[Dict, List] = None
+    train_output: Union[Dict, List[Dict]] = None
     # eval
     eval_value: float = -np.inf
     last_eval_iter: int = -1
+    eval_output: List = dataclasses.field(default_factory=dict)
 
     def __post_init__(self):
         # This method is called just after __init__ method. Here, concretely speaking,
