@@ -1,3 +1,4 @@
+import uuid
 from ditk import logging
 from time import sleep
 from typing import Tuple
@@ -21,13 +22,16 @@ class RedisMQ(MQ):
         self.host = redis_host
         self.port = redis_port if isinstance(redis_port, int) else int(redis_port)
         self.db = 0
-        self._finished = False
+        self._running = False
+        self._id = uuid.uuid4().hex.encode()
 
     def listen(self) -> None:
         self._client = client = redis.Redis(host=self.host, port=self.port, db=self.db)
         self._sub = client.pubsub()
+        self._running = True
 
     def publish(self, topic: str, data: bytes) -> None:
+        data = self._id + b"::" + data
         self._client.publish(topic, data)
 
     def subscribe(self, topic: str) -> None:
@@ -38,23 +42,30 @@ class RedisMQ(MQ):
 
     def recv(self) -> Tuple[str, bytes]:
         while True:
-            if self._finished:
-                return
+            if not self._running:
+                raise RuntimeError("Redis MQ was not running!")
             try:
                 msg = self._sub.get_message(ignore_subscribe_messages=True)
                 if msg is None:
                     sleep(0.001)
                     continue
                 topic = msg["channel"].decode()
-                data = msg["data"]
+                data = msg["data"].split(b"::", maxsplit=1)
+                if len(data) != 2 or len(data[0]) != 32:
+                    logging.warn("Got invalid message from topic: {}".format(topic))
+                    continue
+                node_id, data = data
+                if node_id == self._id:  # Discard message sent by self
+                    continue
                 return topic, data
             except (OSError, AttributeError, Exception) as e:
                 logging.error("Meet exception when listening for new messages", e)
 
     def stop(self) -> None:
-        self._finished = True
-        self._sub.close()
-        self._client.close()
+        if self._running:
+            self._running = False
+            self._sub.close()
+            self._client.close()
 
     def __del__(self) -> None:
         self.stop()
