@@ -6,7 +6,8 @@ from .vac import VAC
 from .bc import DiscreteBC, ContinuousBC
 # algorithm-specific
 from .ppg import PPG
-from .qmix import Mixer, QMix, CollaQ
+from .qmix import Mixer, QMix
+from .collaq import CollaQ
 from .wqmix import WQMix
 from .coma import COMA
 from .atoc import ATOC
