@@ -3,7 +3,7 @@ from .collection_helper import iter_mapping
 from .compression_helper import get_data_compressor, get_data_decompressor
 from .default_helper import override, dicts_to_lists, lists_to_dicts, squeeze, default_get, error_wrapper, list_split, \
     LimitedSpaceContainer, deep_merge_dicts, set_pkg_seed, flatten_dict, one_time_warning, split_data_generator, \
-    RunningMeanStd, make_key_as_identifier
+    RunningMeanStd, make_key_as_identifier, remove_illegal_item
 from .design_helper import SingletonMetaclass
 from .file_helper import read_file, save_file, remove_file
 from .import_helper import try_import_ceph, try_import_mc, try_import_link, import_module, try_import_redis, \
@@ -20,7 +20,7 @@ from .registry_factory import registries, POLICY_REGISTRY, ENV_REGISTRY, LEARNER
     SERIAL_COLLECTOR_REGISTRY, PARALLEL_COLLECTOR_REGISTRY, COMM_COLLECTOR_REGISTRY, \
     COMMANDER_REGISTRY, LEAGUE_REGISTRY, PLAYER_REGISTRY, MODEL_REGISTRY, ENV_MANAGER_REGISTRY, ENV_WRAPPER_REGISTRY, \
     REWARD_MODEL_REGISTRY, BUFFER_REGISTRY, DATASET_REGISTRY, SERIAL_EVALUATOR_REGISTRY, MQ_REGISTRY, \
-    WORLD_MODEL_REGISTRY
+    WORLD_MODEL_REGISTRY, STOCHASTIC_OPTIMIZER_REGISTRY
 from .scheduler_helper import Scheduler
 from .segment_tree import SumSegmentTree, MinSegmentTree, SegmentTree
 from .slurm_helper import find_free_port_slurm, node_to_host, node_to_partition
