@@ -373,7 +373,7 @@ class BaseLearner(object):
         ret = {
             'learner_step': self._last_iter.val,
             'priority_info': self.priority_info,
-            'learner_done': self._learner_done
+            'learner_done': self._learner_done,
         }
         return ret
 
