@@ -7,9 +7,7 @@ from ding.envs import NoopResetWrapper, MaxAndSkipWrapper, EpisodicLifeWrapper,
     ScaledFloatFrameWrapper, \
     ClipRewardWrapper, FrameStackWrapper
 import numpy as np
-from ding.rl_utils.efficientzero.game import Game
 from ding.utils.compression_helper import jpeg_data_compressor
-from gym.wrappers import RecordVideo
 import cv2
 
 
@@ -75,42 +73,6 @@ def wrap_deepmind_mr(env_id, episode_life=True, clip_rewards=True, frame_stack=4
     return env
 
 
-"""
-The following code is adapted from https://github.com/YeWR/EfficientZero
-"""
-
-
-def wrap_muzero(config, warp_frame=True, save_video=False, save_path=None, video_callable=None, uid=None):
-    """
-    Overview:
-        Configure environment for MuZero-style Atari. The observation is
-        channel-first: (c, h, w) instead of (h, w, c).
-    Arguments:
-        - config (:obj:`Dict`): Dict containing configuration.
-    :param str env_id: the atari environment id.
-    :param bool config.episode_life: wrap the episode life wrapper.
-    :param bool warp_frame: wrap the grayscale + resize observation wrapper.
-    :return: the wrapped atari environment.
-    """
-    env = gym.make(config.env_name)
-    assert 'NoFrameskip' in env.spec.id
-    env = NoopResetWrapper(env, noop_max=30)
-    env = MaxAndSkipWrapper(env, skip=4)
-    if config.episode_life:
-        env = EpisodicLifeWrapper(env)
-    env = TimeLimit(env, max_episode_steps=config.max_episode_steps)
-    if warp_frame:
-        env = WarpFrame(env, width=config.obs_shape[1], height=config.obs_shape[2], grayscale=config.gray_scale)
-    if save_video:
-        #env = Monitor(env, directory=save_path, force=True, video_callable=video_callable, uid=uid)
-        env = RecordVideo(env, video_folder=save_path, episode_trigger=lambda episode_id: True, name_prefix='rl-video-{}'.format(uid))
-    env = JpegWrapper(env, cvt_string=config.cvt_string)
-    if config.game_wrapper:
-        env = GameWrapper(env)
-
-    return env
-
-
 class TimeLimit(gym.Wrapper):
 
     def __init__(self, env, max_episode_steps=None):
