@@ -2,6 +2,8 @@ import pytest
 import numpy as np
 import gym
 from easydict import EasyDict
+import atari_py
+
 from dizoo.atari.envs import AtariEnv, AtariEnvMR
 
 
@@ -15,16 +17,24 @@ class TestAtariEnv:
         pong_env.seed(0)
         obs = pong_env.reset()
         assert obs.shape == (cfg.frame_stack, 84, 84)
-        act_dim = pong_env.info().act_space.shape[0]
+        act_dim = pong_env.action_space.n
+        i = 0
         while True:
-            random_action = np.random.choice(range(act_dim), size=(1, ))
+            # Both ``env.random_action()``, and utilizing ``np.random`` as well as action space,
+            # can generate legal random action.
+            if i < 10:
+                random_action = np.random.choice(range(act_dim), size=(1, ))
+                i += 1
+            else:
+                random_action = pong_env.random_action()
             timestep = pong_env.step(random_action)
             assert timestep.obs.shape == (cfg.frame_stack, 84, 84)
             assert timestep.reward.shape == (1, )
             if timestep.done:
                 assert 'final_eval_reward' in timestep.info, timestep.info
                 break
-        print(pong_env.info(), 'final_eval_reward: {}'.format(timestep.info['final_eval_reward']))
+        print(pong_env.observation_space, pong_env.action_space, pong_env.reward_space)
+        print('final_eval_reward: {}'.format(timestep.info['final_eval_reward']))
         pong_env.close()
 
     def test_montezuma_revenge(self):
@@ -34,22 +44,20 @@ class TestAtariEnv:
         mr_env.seed(0)
         obs = mr_env.reset()
         assert obs.shape == (cfg.frame_stack, 84, 84)
-        act_dim = mr_env.info().act_space.shape[0]
+        act_dim = mr_env.action_space.n
+        i = 0
         while True:
-            random_action = np.random.choice(range(act_dim), size=(1, ))
+            if i < 10:
+                random_action = np.random.choice(range(act_dim), size=(1, ))
+                i += 1
+            else:
+                random_action = mr_env.random_action()
             timestep = mr_env.step(random_action)
             assert timestep.obs.shape == (cfg.frame_stack, 84, 84)
             assert timestep.reward.shape == (1, )
             if timestep.done:
                 assert 'final_eval_reward' in timestep.info, timestep.info
                 break
-        print(mr_env.info(), 'final_eval_reward: {}'.format(timestep.info['final_eval_reward']))
+        print(mr_env.observation_space, mr_env.action_space, mr_env.reward_space)
+        print('final_eval_reward: {}'.format(timestep.info['final_eval_reward']))
         mr_env.close()
-
-    def test_info(self):
-        cfg = {'env_id': 'PongNoFrameskip-v4', 'frame_stack': 4, 'is_train': True}
-        cfg = EasyDict(cfg)
-        pong_env = AtariEnv(cfg)
-        info_dict = pong_env.info()
-        print(info_dict)
-        pong_env.close()
