@@ -13,18 +13,16 @@ class TestBipedalWalkerEnv:
         assert env._seed == 123
         obs = env.reset()
         assert obs.shape == (24, )
-        act_val = env.info().act_space.value
-        min_val, max_val = act_val['min'], act_val['max']
         for i in range(10):
-            random_action = np.random.randint(min_val, max_val, size=(4, ))
+            random_action = env.random_action()
             timestep = env.step(random_action)
             print(timestep)
             assert isinstance(timestep.obs, np.ndarray)
             assert isinstance(timestep.done, bool)
             assert timestep.obs.shape == (24, )
             assert timestep.reward.shape == (1, )
-            assert timestep.reward >= env.info().rew_space.value['min']
-            assert timestep.reward <= env.info().rew_space.value['max']
+            assert timestep.reward >= env.reward_space.low
+            assert timestep.reward <= env.reward_space.high
             # assert isinstance(timestep, tuple)
-        print(env.info())
+        print(env.observation_space, env.action_space, env.reward_space)
         env.close()
