@@ -1,5 +1,5 @@
 from .lunarlander_dqn_config import lunarlander_dqn_config, lunarlander_dqn_create_config
-from .lunarlander_dqn_gail_config import lunarlander_dqn_gail_create_config, lunarlander_dqn_gail_config
+from .lunarlander_gail_dqn_config import lunarlander_dqn_gail_create_config, lunarlander_dqn_gail_config
 from .lunarlander_dqfd_config import lunarlander_dqfd_config, lunarlander_dqfd_create_config
 from .lunarlander_qrdqn_config import lunarlander_qrdqn_config, lunarlander_qrdqn_create_config
 from .lunarlander_trex_dqn_config import lunarlander_trex_dqn_config, lunarlander_trex_dqn_create_config
