@@ -1,14 +1,12 @@
-import ding
-from copy import deepcopy
-from ding.entry import serial_pipeline
 from easydict import EasyDict
 
 lunarlander_qrdqn_config = dict(
+    exp_name='lunarlander_qrdqn_seed0',
     env=dict(
         collector_env_num=8,
-        evaluator_env_num=5,
+        evaluator_env_num=8,
         env_id='LunarLander-v2',
-        n_evaluator_episode=5,
+        n_evaluator_episode=8,
         stop_value=200,
     ),
     policy=dict(
@@ -43,11 +41,13 @@ lunarlander_qrdqn_create_config = dict(
         type='lunarlander',
         import_names=['dizoo.box2d.lunarlander.envs.lunarlander_env'],
     ),
-    env_manager=dict(type='base'),
+    env_manager=dict(type='subprocess'),
     policy=dict(type='qrdqn'),
 )
 lunarlander_qrdqn_create_config = EasyDict(lunarlander_qrdqn_create_config)
 create_config = lunarlander_qrdqn_create_config
 
 if __name__ == '__main__':
-    serial_pipeline((main_config, create_config), seed=0)
+    # or you can enter `ding -m serial -c lunarlander_qrdqn_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline([main_config, create_config], seed=0)
