@@ -1,6 +1,7 @@
 from easydict import EasyDict
 
 cartpole_iqn_config = dict(
+    exp_name='cartpole_iqn_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -9,7 +10,6 @@ cartpole_iqn_config = dict(
     ),
     policy=dict(
         cuda=False,
-        priority=True,
         model=dict(
             obs_shape=4,
             action_shape=2,
@@ -51,3 +51,8 @@ cartpole_iqn_create_config = dict(
 )
 cartpole_iqn_create_config = EasyDict(cartpole_iqn_create_config)
 create_config = cartpole_iqn_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c cartpole_iqn_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline((main_config, create_config), seed=0)
