@@ -1,7 +1,7 @@
 from easydict import EasyDict
 
 cartpole_qrdqn_config = dict(
-    exp_name='cartpole_qrdqn',
+    exp_name='cartpole_qrdqn_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -10,7 +10,6 @@ cartpole_qrdqn_config = dict(
     ),
     policy=dict(
         cuda=False,
-        priority=True,
         model=dict(
             obs_shape=4,
             action_shape=2,
@@ -53,3 +52,8 @@ cartpole_qrdqn_create_config = dict(
 )
 cartpole_qrdqn_create_config = EasyDict(cartpole_qrdqn_create_config)
 create_config = cartpole_qrdqn_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c cartpole_qrdqn_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline((main_config, create_config), seed=0)
