@@ -1,7 +1,7 @@
 from easydict import EasyDict
 
 cartpole_sql_config = dict(
-    exp_name='cartpole_sql',
+    exp_name='cartpole_sql_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=5,
@@ -44,3 +44,8 @@ cartpole_sql_create_config = dict(
 )
 cartpole_sql_create_config = EasyDict(cartpole_sql_create_config)
 create_config = cartpole_sql_create_config
+
+if __name__ == "__main__":
+    # or you can enter `ding -m serial -c cartpole_sql_config.py -s 0`
+    from ding.entry import serial_pipeline
+    serial_pipeline((main_config, create_config), seed=0)
