@@ -1,7 +1,7 @@
 from easydict import EasyDict
 
 pendulum_td3_generation_config = dict(
-    exp_name='td3',
+    exp_name='pendulum_td3_generation_seed0',
     env=dict(
         collector_env_num=8,
         evaluator_env_num=10,
@@ -65,3 +65,7 @@ pendulum_td3_generation_create_config = dict(
 )
 pendulum_td3_generation_create_config = EasyDict(pendulum_td3_generation_create_config)
 create_config = pendulum_td3_generation_create_config
+
+if __name__ == "__main__":
+    from ding.entry import collect_demo_data
+    collect_demo_data([main_config, create_config], seed=0)
