@@ -1,19 +1,18 @@
 from ding.entry import serial_pipeline_offline
 from ding.config import read_config
-import os
+from pathlib import Path
 
 
 def train(args):
-    if '../config' in args.config:
-        config = read_config(args.config)
-    else:
-        config = read_config(os.path.join('../config/', args.config))
+    # launch from anywhere
+    config = Path(__file__).absolute().parent.parent / 'config' / args.config 
+    config = read_config(str(config))
+    config[0].exp_name = config[0].exp_name.replace('0', str(args.seed))
     serial_pipeline_offline(config, seed=args.seed)
 
 
 if __name__ == "__main__":
     import argparse
-    from d4rl import set_dataset_path
 
     parser = argparse.ArgumentParser()
     parser.add_argument('--seed', '-s', type=int, default=10)
