@@ -1,24 +1,31 @@
+from typing import List
 import numpy as np
+import gym
+
 from ding.envs import BaseEnv, BaseEnvTimestep
 
 
 class GameEnv(BaseEnv):
 
-    def __init__(self, game_type='prisoner_dilemma'):
+    def __init__(self, game_type: str = 'prisoner_dilemma') -> None:
         self.game_type = game_type
         assert self.game_type in ['zero_sum', 'prisoner_dilemma']
         if self.game_type == 'prisoner_dilemma':
             self.optimal_policy = [0, 1]
         elif self.game_type == 'zero_sum':
             self.optimal_policy = [0.375, 0.625]
+        self._observation_space = None
+        self._action_space = None
+        self._reward_space = None
 
-    def seed(self, seed, dynamic_seed=False):
+    def seed(self, seed: int, dynamic_seed: bool = False) -> None:
+        # ignore seed
         pass
 
-    def reset(self):
+    def reset(self) -> np.ndarray:
         return np.array([[0, 1], [1, 0]]).astype(np.float32)  # trivial observation
 
-    def step(self, actions):
+    def step(self, actions: List[int]) -> BaseEnvTimestep:
         if self.game_type == 'zero_sum':
             if actions == [0, 0]:
                 rewards = 3, -3
@@ -62,11 +69,23 @@ class GameEnv(BaseEnv):
         }
         return BaseEnvTimestep(observations, rewards, True, infos)
 
-    def close(self):
+    def close(self) -> None:
         pass
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return "DI-engine League Demo GameEnv"
 
-    def info(self):
-        pass
+    @property
+    def observation_space(self) -> gym.spaces.Space:
+        return self._observation_space
+
+    @property
+    def action_space(self) -> gym.spaces.Space:
+        return self._action_space
+
+    @property
+    def reward_space(self) -> gym.spaces.Space:
+        return self._reward_space
+
+    def random_action(self) -> List[int]:
+        return [np.random.randint(0, 2) for _ in range(2)]
