@@ -5,11 +5,12 @@ import copy
 import os
 import time
 import gym
+import gymnasium
+
 import numpy as np
 from matplotlib import animation
 import matplotlib.pyplot as plt
-from gym_minigrid.wrappers import FlatObsWrapper, RGBImgPartialObsWrapper, ImgObsWrapper, ViewSizeWrapper
-from gym_minigrid.window import Window
+from MiniGrid.minigrid.wrappers import FlatObsWrapper, RGBImgPartialObsWrapper, ImgObsWrapper, ViewSizeWrapper
 from ding.envs import ObsPlusPrevActRewWrapper
 
 from ding.envs import BaseEnv, BaseEnvTimestep
@@ -36,12 +37,12 @@ class MiniGridEnv(BaseEnv):
         self._env_id = cfg.env_id
         self._flat_obs = cfg.flat_obs
         self._save_replay = False
-        # self._max_step = MINIGRID_INFO_DICT[self._env_id].max_step
         self._max_step = cfg.max_step
 
     def reset(self) -> np.ndarray:
         if not self._init_flag:
-            self._env = gym.make(self._env_id)
+            self._env = gymnasium.make(self._env_id)  # using the Gymnasium make method
+
             if self._env_id in ['MiniGrid-AKTDT-13x13-v0' or 'MiniGrid-AKTDT-13x13-1-v0']:
                 # customize the agent field of view size, note this must be an odd number
                 # This also related to the observation space, see gym_minigrid.wrappers for more details
@@ -63,15 +64,19 @@ class MiniGridEnv(BaseEnv):
             self._observation_space.dtype = np.dtype('float32')
         self._action_space = self._env.action_space
         self._reward_space = gym.spaces.Box(
-            low=self._env.reward_range[0], high=self._env.reward_range[1], shape=(1, ), dtype=np.float32
+            low=self._env.reward_range[0], high=self._env.reward_range[1], shape=(1,), dtype=np.float32
         )
+
+        self._final_eval_reward = 0
         if hasattr(self, '_seed') and hasattr(self, '_dynamic_seed') and self._dynamic_seed:
             np_seed = 100 * np.random.randint(1, 1000)
-            self._env.seed(self._seed + np_seed)
+            self._seed = self._seed + np_seed
+            obs, _ = self._env.reset(seed=self._seed)  # using the reset method of Gymnasium env
         elif hasattr(self, '_seed'):
-            self._env.seed(self._seed)
-        self._final_eval_reward = 0
-        obs = self._env.reset()
+            obs, _ = self._env.reset(seed=self._seed)
+        else:
+            obs, _ = self._env.reset()
+
         obs = to_ndarray(obs)
         self._current_step = 0
         if self._save_replay:
@@ -91,11 +96,12 @@ class MiniGridEnv(BaseEnv):
 
     def step(self, action: np.ndarray) -> BaseEnvTimestep:
         assert isinstance(action, np.ndarray), type(action)
-        if action.shape == (1, ):
+        if action.shape == (1,):
             action = action.squeeze()  # 0-dim array
         if self._save_replay:
             self._frames.append(self._env.render(mode='rgb_array'))
-        obs, rew, done, info = self._env.step(action)
+        # using the step method of Gymnasium env, return is (observation, reward, terminated, truncated, info)
+        obs, rew, done, _, info = self._env.step(action)
         rew = float(rew)
         self._final_eval_reward += rew
         self._current_step += 1
