@@ -60,7 +60,7 @@ ptz_simple_spread_atoc_config = EasyDict(ptz_simple_spread_atoc_config)
 main_config = ptz_simple_spread_atoc_config
 ptz_simple_spread_atoc_create_config = dict(
     env=dict(
-        import_names=['dizoo.petting_zoo.envs.petting_zoo_env'],
+        import_names=['dizoo.petting_zoo.envs.petting_zoo_simple_spread_env'],
         type='petting_zoo',
     ),
     env_manager=dict(type='subprocess'),
